# Copyright 2017 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# NOTE: This class is auto generated by the swagger code generator program.
# https://github.com/swagger-api/swagger-codegen.git
# Do not edit the class manually.

defmodule GoogleApi.Monitoring.V3.Api.TimeSeries do
  @moduledoc """
  API calls for all endpoints tagged `TimeSeries`.
  """

  alias GoogleApi.Monitoring.V3.Connection
  alias GoogleApi.Gax.{Request, Response}

  @doc """
  Creates or adds data to one or more time series. The response is empty if all time series in the request were written. If any time series could not be written, a corresponding failure message is included in the error response.

  ## Parameters

  - connection (GoogleApi.Monitoring.V3.Connection): Connection to server
  - v3_id (String.t): Part of &#x60;name&#x60;. The project on which to execute the request. The format is \&quot;projects/{project_id_or_number}\&quot;.
  - v3_id1 (String.t): Part of &#x60;name&#x60;. See documentation of &#x60;v3Id&#x60;.
  - optional_params (KeywordList): [optional] Optional parameters
    - :uploadType (String.t): Legacy upload protocol for media (e.g. \&quot;media\&quot;, \&quot;multipart\&quot;).
    - :fields (String.t): Selector specifying which fields to include in a partial response.
    - :callback (String.t): JSONP
    - :oauth_token (String.t): OAuth 2.0 token for the current user.
    - :$.xgafv (String.t): V1 error format.
    - :alt (String.t): Data format for response.
    - :key (String.t): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
    - :access_token (String.t): OAuth access token.
    - :upload_protocol (String.t): Upload protocol for media (e.g. \&quot;raw\&quot;, \&quot;multipart\&quot;).
    - :quotaUser (String.t): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
    - :prettyPrint (boolean()): Returns response with indentations and line breaks.
    - :body (CreateTimeSeriesRequest): 

  ## Returns

  {:ok, %GoogleApi.Monitoring.V3.Model.Empty{}} on success
  {:error, info} on failure
  """
  @spec monitoring_time_series_create(Tesla.Env.client(), String.t(), String.t(), keyword()) ::
          {:ok, GoogleApi.Monitoring.V3.Model.Empty.t()} | {:error, Tesla.Env.t()}
  def monitoring_time_series_create(connection, v3_id, v3_id1, optional_params \\ [], opts \\ []) do
    optional_params_config = %{
      :uploadType => :query,
      :fields => :query,
      :callback => :query,
      :oauth_token => :query,
      :"$.xgafv" => :query,
      :alt => :query,
      :key => :query,
      :access_token => :query,
      :upload_protocol => :query,
      :quotaUser => :query,
      :prettyPrint => :query,
      :body => :body
    }

    request =
      Request.new()
      |> Request.method(:post)
      |> Request.url("/v3/{v3Id}/{v3Id1}/timeSeries", %{
        "v3Id" => URI.encode_www_form(v3_id),
        "v3Id1" => URI.encode_www_form(v3_id1)
      })
      |> Request.add_optional_params(optional_params_config, optional_params)

    connection
    |> Connection.execute(request)
    |> Response.decode(opts ++ [struct: %GoogleApi.Monitoring.V3.Model.Empty{}])
  end

  @doc """
  Lists time series that match a filter. This method does not require a Stackdriver account.

  ## Parameters

  - connection (GoogleApi.Monitoring.V3.Connection): Connection to server
  - v3_id (String.t): Part of &#x60;name&#x60;. The project on which to execute the request. The format is \&quot;projects/{project_id_or_number}\&quot;.
  - v3_id1 (String.t): Part of &#x60;name&#x60;. See documentation of &#x60;v3Id&#x60;.
  - optional_params (KeywordList): [optional] Optional parameters
    - :uploadType (String.t): Legacy upload protocol for media (e.g. \&quot;media\&quot;, \&quot;multipart\&quot;).
    - :fields (String.t): Selector specifying which fields to include in a partial response.
    - :callback (String.t): JSONP
    - :oauth_token (String.t): OAuth 2.0 token for the current user.
    - :$.xgafv (String.t): V1 error format.
    - :alt (String.t): Data format for response.
    - :key (String.t): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
    - :access_token (String.t): OAuth access token.
    - :upload_protocol (String.t): Upload protocol for media (e.g. \&quot;raw\&quot;, \&quot;multipart\&quot;).
    - :quotaUser (String.t): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
    - :prettyPrint (boolean()): Returns response with indentations and line breaks.
    - :aggregation.groupByFields ([String.t]): The set of fields to preserve when crossSeriesReducer is specified. The groupByFields determine how the time series are partitioned into subsets prior to applying the aggregation function. Each subset contains time series that have the same value for each of the grouping fields. Each individual time series is a member of exactly one subset. The crossSeriesReducer is applied to each subset of time series. It is not possible to reduce across different resource types, so this field implicitly contains resource.type. Fields not specified in groupByFields are aggregated away. If groupByFields is not specified and all the time series have the same resource type, then the time series are aggregated into a single output time series. If crossSeriesReducer is not defined, this field is ignored.
    - :interval.endTime (DateTime.t): Required. The end of the time interval.
    - :aggregation.alignmentPeriod (String.t): The alignment period for per-time series alignment. If present, alignmentPeriod must be at least 60 seconds. After per-time series alignment, each time series will contain data points only on the period boundaries. If perSeriesAligner is not specified or equals ALIGN_NONE, then this field is ignored. If perSeriesAligner is specified and does not equal ALIGN_NONE, then this field must be defined; otherwise an error is returned.
    - :pageSize (integer()): A positive number that is the maximum number of results to return. If page_size is empty or more than 100,000 results, the effective page_size is 100,000 results. If view is set to FULL, this is the maximum number of Points returned. If view is set to HEADERS, this is the maximum number of TimeSeries returned.
    - :orderBy (String.t): Unsupported: must be left blank. The points in each time series are returned in reverse time order.
    - :aggregation.crossSeriesReducer (String.t): The approach to be used to combine time series. Not all reducer functions may be applied to all time series, depending on the metric type and the value type of the original time series. Reduction may change the metric type of value type of the time series.Time series data must be aligned in order to perform cross-time series reduction. If crossSeriesReducer is specified, then perSeriesAligner must be specified and not equal ALIGN_NONE and alignmentPeriod must be specified; otherwise, an error is returned.
    - :filter (String.t): A monitoring filter that specifies which time series should be returned. The filter must specify a single metric type, and can additionally specify metric labels and other information. For example: metric.type &#x3D; \&quot;compute.googleapis.com/instance/cpu/usage_time\&quot; AND     metric.label.instance_name &#x3D; \&quot;my-instance-name\&quot; 
    - :pageToken (String.t): If this field is not empty then it must contain the nextPageToken value returned by a previous call to this method. Using this field causes the method to return additional results from the previous method call.
    - :aggregation.perSeriesAligner (String.t): The approach to be used to align individual time series. Not all alignment functions may be applied to all time series, depending on the metric type and value type of the original time series. Alignment may change the metric type or the value type of the time series.Time series data must be aligned in order to perform cross-time series reduction. If crossSeriesReducer is specified, then perSeriesAligner must be specified and not equal ALIGN_NONE and alignmentPeriod must be specified; otherwise, an error is returned.
    - :interval.startTime (DateTime.t): Optional. The beginning of the time interval. The default value for the start time is the end time. The start time must not be later than the end time.
    - :view (String.t): Specifies which information is returned about the time series.

  ## Returns

  {:ok, %GoogleApi.Monitoring.V3.Model.ListTimeSeriesResponse{}} on success
  {:error, info} on failure
  """
  @spec monitoring_time_series_list(Tesla.Env.client(), String.t(), String.t(), keyword()) ::
          {:ok, GoogleApi.Monitoring.V3.Model.ListTimeSeriesResponse.t()}
          | {:error, Tesla.Env.t()}
  def monitoring_time_series_list(connection, v3_id, v3_id1, optional_params \\ [], opts \\ []) do
    optional_params_config = %{
      :uploadType => :query,
      :fields => :query,
      :callback => :query,
      :oauth_token => :query,
      :"$.xgafv" => :query,
      :alt => :query,
      :key => :query,
      :access_token => :query,
      :upload_protocol => :query,
      :quotaUser => :query,
      :prettyPrint => :query,
      :"aggregation.groupByFields" => :query,
      :"interval.endTime" => :query,
      :"aggregation.alignmentPeriod" => :query,
      :pageSize => :query,
      :orderBy => :query,
      :"aggregation.crossSeriesReducer" => :query,
      :filter => :query,
      :pageToken => :query,
      :"aggregation.perSeriesAligner" => :query,
      :"interval.startTime" => :query,
      :view => :query
    }

    request =
      Request.new()
      |> Request.method(:get)
      |> Request.url("/v3/{v3Id}/{v3Id1}/timeSeries", %{
        "v3Id" => URI.encode_www_form(v3_id),
        "v3Id1" => URI.encode_www_form(v3_id1)
      })
      |> Request.add_optional_params(optional_params_config, optional_params)

    connection
    |> Connection.execute(request)
    |> Response.decode(opts ++ [struct: %GoogleApi.Monitoring.V3.Model.ListTimeSeriesResponse{}])
  end
end
