# Copyright 2017 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# NOTE: This class is auto generated by the swagger code generator program.
# https://github.com/swagger-api/swagger-codegen.git
# Do not edit the class manually.

defmodule GoogleApi.Monitoring.V3.Model.MetricDescriptor do
  @moduledoc """
  Defines a metric type and its schema. Once a metric descriptor is created, deleting or altering it stops data collection and makes the metric type&#39;s existing data unusable.

  ## Attributes

  - description (String.t): A detailed description of the metric, which can be used in documentation. Defaults to: `null`.
  - displayName (String.t): A concise name for the metric, which can be displayed in user interfaces. Use sentence case without an ending period, for example \&quot;Request count\&quot;. This field is optional but it is recommended to be set for any metrics associated with user-visible concepts, such as Quota. Defaults to: `null`.
  - labels ([LabelDescriptor]): The set of labels that can be used to describe a specific instance of this metric type. For example, the appengine.googleapis.com/http/server/response_latencies metric type has a label for the HTTP response code, response_code, so you can look at latencies for successful responses or just for responses that failed. Defaults to: `null`.
  - launchStage (String.t): Optional. The launch stage of the metric definition. Defaults to: `null`.
    - Enum - one of [LAUNCH_STAGE_UNSPECIFIED, EARLY_ACCESS, ALPHA, BETA, GA, DEPRECATED]
  - metadata (MetricDescriptorMetadata): Optional. Metadata which can be used to guide usage of the metric. Defaults to: `null`.
  - metricKind (String.t): Whether the metric records instantaneous values, changes to a value, etc. Some combinations of metric_kind and value_type might not be supported. Defaults to: `null`.
    - Enum - one of [METRIC_KIND_UNSPECIFIED, GAUGE, DELTA, CUMULATIVE]
  - name (String.t): The resource name of the metric descriptor. Defaults to: `null`.
  - type (String.t): The metric type, including its DNS name prefix. The type is not URL-encoded. All user-defined metric types have the DNS name custom.googleapis.com or external.googleapis.com. Metric types should use a natural hierarchical grouping. For example: \&quot;custom.googleapis.com/invoice/paid/amount\&quot; \&quot;external.googleapis.com/prometheus/up\&quot; \&quot;appengine.googleapis.com/http/server/response_latencies\&quot;  Defaults to: `null`.
  - unit (String.t): The unit in which the metric value is reported. It is only applicable if the value_type is INT64, DOUBLE, or DISTRIBUTION. The supported units are a subset of The Unified Code for Units of Measure (http://unitsofmeasure.org/ucum.html) standard:Basic units (UNIT) bit bit By byte s second min minute h hour d dayPrefixes (PREFIX) k kilo (10**3) M mega (10**6) G giga (10**9) T tera (10**12) P peta (10**15) E exa (10**18) Z zetta (10**21) Y yotta (10**24) m milli (10**-3) u micro (10**-6) n nano (10**-9) p pico (10**-12) f femto (10**-15) a atto (10**-18) z zepto (10**-21) y yocto (10**-24) Ki kibi (2**10) Mi mebi (2**20) Gi gibi (2**30) Ti tebi (2**40)GrammarThe grammar also includes these connectors: / division (as an infix operator, e.g. 1/s). . multiplication (as an infix operator, e.g. GBy.d)The grammar for a unit is as follows: Expression &#x3D; Component { \&quot;.\&quot; Component } { \&quot;/\&quot; Component } ;  Component &#x3D; ( [ PREFIX ] UNIT | \&quot;%\&quot; ) [ Annotation ]           | Annotation           | \&quot;1\&quot;           ;  Annotation &#x3D; \&quot;{\&quot; NAME \&quot;}\&quot; ; Notes: Annotation is just a comment if it follows a UNIT and is  equivalent to 1 if it is used alone. For examples,  {requests}/s &#x3D;&#x3D; 1/s, By{transmitted}/s &#x3D;&#x3D; By/s. NAME is a sequence of non-blank printable ASCII characters not  containing &#39;{&#39; or &#39;}&#39;. 1 represents dimensionless value 1, such as in 1/s. % represents dimensionless value 1/100, and annotates values giving  a percentage. Defaults to: `null`.
  - valueType (String.t): Whether the measurement is an integer, a floating-point number, etc. Some combinations of metric_kind and value_type might not be supported. Defaults to: `null`.
    - Enum - one of [VALUE_TYPE_UNSPECIFIED, BOOL, INT64, DOUBLE, STRING, DISTRIBUTION, MONEY]
  """

  use GoogleApi.Gax.ModelBase

  @type t :: %__MODULE__{
          :description => any(),
          :displayName => any(),
          :labels => list(GoogleApi.Monitoring.V3.Model.LabelDescriptor.t()),
          :launchStage => any(),
          :metadata => GoogleApi.Monitoring.V3.Model.MetricDescriptorMetadata.t(),
          :metricKind => any(),
          :name => any(),
          :type => any(),
          :unit => any(),
          :valueType => any()
        }

  field(:description)
  field(:displayName)
  field(:labels, as: GoogleApi.Monitoring.V3.Model.LabelDescriptor, type: :list)
  field(:launchStage)
  field(:metadata, as: GoogleApi.Monitoring.V3.Model.MetricDescriptorMetadata)
  field(:metricKind)
  field(:name)
  field(:type)
  field(:unit)
  field(:valueType)
end

defimpl Poison.Decoder, for: GoogleApi.Monitoring.V3.Model.MetricDescriptor do
  def decode(value, options) do
    GoogleApi.Monitoring.V3.Model.MetricDescriptor.decode(value, options)
  end
end

defimpl Poison.Encoder, for: GoogleApi.Monitoring.V3.Model.MetricDescriptor do
  def encode(value, options) do
    GoogleApi.Gax.ModelBase.encode(value, options)
  end
end
